@@ -21,3 +21,5 @@ from svix.openapi_client.api.event_type_api import EventTypeApi
 from svix.openapi_client.api.health_api import HealthApi
 from svix.openapi_client.api.message_api import MessageApi
 from svix.openapi_client.api.message_attempt_api import MessageAttemptApi
+from svix.openapi_client.api.organization_settings_api import OrganizationSettingsApi
+from svix.openapi_client.api.statistics_api import StatisticsApi
